@@ -10,7 +10,7 @@ Kernel-Debian_32bit
 </name>
 
 <description>  
-Fallback Debian 4.9 32bit linux kernel 
+Fallback Debian 4.19 32bit linux kernel 
 </description>
 
 <installable>
@@ -20,13 +20,11 @@ Fallback Debian 4.9 32bit linux kernel
 <screenshot>none</screenshot>
 
 <preinstall>
-echo "---- in preprocessing ----"
-echo "---- preprocessing done----"
 </preinstall>
 
 <install_package_names>
-linux-image-4.9.0-15-686
-linux-headers-4.9.0-15-686
+linux-image-4.19.0-6-686
+linux-headers-4.19.0-6-686
 </install_package_names>
 
 <postinstall>
@@ -34,8 +32,8 @@ linux-headers-4.9.0-15-686
 </postinstall>
 
 <uninstall_package_names>
-linux-image-4.9.0-15-686
-linux-headers-4.9.0-15-686
+linux-image-4.19.0-6-686
+linux-headers-4.19.0-6-686
 </uninstall_package_names>
 
 </app>
