@@ -20,8 +20,6 @@ all
 <screenshot>none</screenshot>
 
 <preinstall>
-echo "---- in preprocessing ----"
-echo "---- preprocessing done----"
 </preinstall>
 
 <install_package_names>
@@ -33,7 +31,7 @@ libreoffice-math
 libreoffice-writer
 libreoffice-base
 libreoffice-l10n-ml
-libreoffice-gtk
+libreoffice-gtk2
 </install_package_names>
 
 <postinstall>
@@ -49,7 +47,7 @@ libreoffice-math
 libreoffice-writer
 libreoffice-base
 libreoffice-l10n-ml
-libreoffice-gtk
+libreoffice-gtk2
 </uninstall_package_names>
 
 </app>
